#!/usr/bin/env python

import os
import pandas
import re


def join_csv_files():
    with open('timings.csv', 'w') as out:
        for f in os.listdir(os.getcwd()):
            match = re.match(".*rank-([0-9]*).csv", f)
            if match:
                for line in open(f, 'r'):
                    out.write("{} {}".format(match.group(1), line))


def calculate_floprate():
    frame = pandas.read_csv('timings.csv', header=None, names=('rank', 'exec', 'kernel', 'what', 'value'), delimiter=' ')
    time = frame[frame.what == "time"]
    ops = frame[frame.what != "time"]

    time = time.groupby(('rank', 'exec', 'kernel'))['value'].min().to_frame().reset_index().groupby(('exec', 'kernel'))['value'].max()
    ops = ops.groupby(('rank', 'exec', 'kernel'))['value'].max().to_frame().reset_index().groupby(('exec', 'kernel'))['value'].max()

    with open('floprates.csv', 'w') as out:
        for key in time.keys():
            exe, kernel = key
            if "nonopcount" in exe and kernel != "total":
                opexe = exe.replace("nonopcount", "opcount")
                degree = re.match(".*deg([0-9]*).*", exe).group(1)
                out.write(" ".join([exe, degree, kernel, str((ops[opexe][kernel] / time[exe][kernel]) / 1e9)]) + "\n")


def calculate_doftimes():
    frame = pandas.read_csv('timings.csv', header=None, names=('rank', 'exec', 'kernel', 'what', 'value'), delimiter=' ')
    dofs = frame[frame.what == "dofs"]
    time = frame[frame.what == "time"]

    dofs = dofs.groupby(('rank', 'exec', 'kernel'))['value'].max().to_frame().reset_index().groupby(('exec', 'kernel'))['value'].max()
    time = time.groupby(('rank', 'exec', 'kernel'))['value'].min().to_frame().reset_index().groupby(('exec', 'kernel'))['value'].max()

    with open('doftimes.csv', 'w') as out:
        for key in time.keys():
            exe, kernel = key
            degree = re.match(".*deg([0-9]*).*", exe).group(1)
            if "nonopcount" in exe:
                out.write(" ".join([exe, degree, kernel, str(dofs[exe]["dofs"] / time[exe][kernel] / 1e6)]) + "\n")


if __name__ == '__main__':
    join_csv_files()
    calculate_floprate()
    calculate_doftimes()
